/*
  writeExampleESP32.ino - Example file to demonstrate SevenSeg74HC595 class single digit write() method use with a single display
  Created by Gabriel D. Goldman, May, 2023.
  Updated by Gabriel D. Goldman, October, 2023.
  Released into the public domain in accordance with "GPL-3.0-or-later" license terms.
*/
#include <Arduino.h>
#include <SevenSeg-74HC595.h>

// Pin connected to DS of 74HC595 AKA DIO
const uint8_t dio {4}; // // Board pin # of ESP32 WROOM-32 uPesy dev Board
// Pin connected to ST_CP of 74HC595 AKA RCLK
const uint8_t rclk {2}; // Board pin # of ESP32 WROOM-32 uPesy dev Board
// Pin connected to SH_CP of 74HC595 AKA SCLK
const uint8_t sclk {0}; // Board pin # of ESP32 WROOM-32 uPesy dev Board

//Set of variables and constants needed just for Demo purposes

bool testResultOne{};

//Display instance creation
// Creating the instance of the display, the only parameters needed are
// the pins that will be connected to the display module, usually marked as:
// SCLK
// RCLK
// DIO
SevenSeg74HC595 myLedDispOne(sclk, rclk, dio);

void setup()
{

}

void loop()
{  
  
  myLedDispOne.begin();

  //Print a "ruler" indicating the position of each "port"
  testResultOne = myLedDispOne.print("3210");
  vTaskDelay(3000/portTICK_PERIOD_MS);


  //Writing the word "burn" character by character in a random way just to show how we can address each
  //display positon without the need of ".print()" the whole display...
  //Put a 'u' in the port #2
  testResultOne = myLedDispOne.write(0xE3, 2);
  delay(3000);

  //Put a 'n' in the port #0
  testResultOne = myLedDispOne.write(0xAB, 0);
  delay(3000);

  //Put a 'b' in the port #3
  testResultOne = myLedDispOne.write(0x83, 3);
  delay(3000);

  //Put a 'r' in the port #1
  testResultOne = myLedDispOne.write(0xAF, 1);
  delay(3000);


  //Now restore the original display one by one using the string overloaded write() method
  // testResultOne = myLedDispOne.write("0", 0);
  delay(3000);
  testResultOne = myLedDispOne.write("2", 2);
  delay(3000);
  testResultOne = myLedDispOne.write("1", 1);
  delay(3000);
  testResultOne = myLedDispOne.write("3", 3);
  delay(3000);
  testResultOne = myLedDispOne.write("0", 0);
  delay(3000);


  //Stop and disengage the display from the ISR... and this is the end of the loop()
  myLedDispOne.clear();
  myLedDispOne.stop();
  vTaskDelay(1000/portTICK_PERIOD_MS);
}